#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Most fault tolerant protocols (including RAFT, PBFT, Zyzzyva, Q/U)
don't guarantee good performance when there are Byzantine faults. Even
the so-called "robust" BFT protocols (like UpRight, RBFT, Prime,
Spinning, and Stellar) have various hard-coded timeout parameters, and
can only guarantee performance when the network behaves approximately as
expected - hence they are best suited to well-controlled settings like
corporate data centers.

HoneyBadgerBFT is fault tolerance for the wild wild wide-area-network.
HoneyBadger nodes can even stay hidden behind anonymizing relays like
Tor, and the purely-asynchronous protocol will make progress at whatever
rate the network supports.

"""
from setuptools import setup


setup(
    name='honeybadgerbft',
    version='0.0.0',
    description='The Honey Badger of BFT Protocols',
    long_description=__doc__,
    author="Andrew Miller et al.",
    url='https://github.com/amiller/HoneyBadgerBFT',
    packages=['honeybadgerbft'],
    package_dir={'honeybadgerbft': 'honeybadgerbft'},
    license='CRAPL',
    zip_safe=False,
    keywords='distributed systems, cryptography, byzantine fault tolerance',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 2 :: Only',
        'Programming Language :: Python :: 2.7',
    ],
)
